"""Profanity check exposed methods"""

import sys

#
# Checks below
#
if sys.version_info.minor > 8:
    from importlib import resources
else:
    import pkg_resources

import numpy as np
import joblib

if sys.version_info.minor > 8:
    vectorizer = joblib.load(
        resources.files("profanity_check") / "data" / "vectorizer.joblib"
    )
    model = joblib.load(resources.files("profanity_check") / "data" / "model.joblib")
else:
    vectorizer = joblib.load(
        pkg_resources.resource_filename("profanity_check", "data/vectorizer.joblib")
    )
    model = joblib.load(
        pkg_resources.resource_filename("profanity_check", "data/model.joblib")
    )


def _get_profane_prob(prob):
    return prob[1]


def predict(texts):
    """Predict texts array"""
    return model.predict(vectorizer.transform(texts))


def predict_prob(texts):
    """Predict texts array returning probabilities"""
    return np.apply_along_axis(
        _get_profane_prob, 1, model.predict_proba(vectorizer.transform(texts))
    )



"""(Mostly smoke) tests"""

from profanity_check import predict, predict_prob


def test_accuracy():
    """Tests with sample text"""
    # pylint:disable=consider-using-enumerate,consider-using-in
    texts = [
        "Hello there, how are you",
        "Lorem Ipsum is simply dummy text of the printing and typesetting industry.",
        "!!!! Click this now!!! -> https://example.com",
        "fuck you",
        "fUcK u",
        "GO TO hElL, you dirty scum",
    ]
    assert list(predict(texts)) == [0, 1, 0, 1, 1, 1]

    probabilities = predict_prob(texts)
    for i in range(len(probabilities)):
        if i == 0 or i == 2:
            assert probabilities[i] <= 0.5
        else:
            assert probabilities[i] >= 0.5


def test_edge_cases():
    """Edge cases: empty and long strings"""
    texts = [
        "",
        "                    ",
        (
            "this is but a test string, "
            "there is no offensive language to be found here! :) "
        )
        * 25,
        "aaaaaaa" * 100,
    ]
    assert list(predict(texts)) == [0, 0, 0, 0]
